@@ -12,10 +12,13 @@ class Finding:
         self.id = kwargs.get('id')
         self.target = kwargs.get('target', '')
         self.controlId = kwargs.get('controlId', '')
-        self.Reason = []
+        self.Reason = kwargs.get('reason', [])
         self.Identifier = kwargs.get('identifier', '')
+        self.IdentifierType = kwargs.get('identifier_type', '')
 
     def json(self) -> dict:
-        return self.__dict__
+        json_obj = self.__dict__
+        json_obj['Reason'] = '\n'.join(self.Reason)
+        return json_obj
 
 # TO-DO: Add classes for targets
